Data from Woollam instruments¶
The reader supports VASE/CompleteEASE ellipsometry files exported from J.A. Woollam instruments in the .dat format, via WoollamParser.
- Parser:
src/pynxtools_ellips/parsers/woollam.py - Config file:
src/pynxtools_ellips/config/config_woollam.json
See Learn > Reader architecture for how the pieces fit together.
Example¶
An example dataset can be found here. Both the ELN file and the .dat data file need to be passed:
pynx convert examples/eln_data.yaml examples/test-data.dat --reader ellips --nxdl NXellipsometry --output SiO2onSi.nxs
See Tutorial > Convert your first ellipsometry dataset for a walkthrough.
Acknowledgments¶
We thank Carola Emminger and Chris Sturm for providing the implementation and respective example data for this reader.